# eric7.WebBrowser.AdBlock

Package implementing the advertisements blocker functionality.

### Modules

AdBlockDialog | Module implementing the AdBlock configuration dialog.
AdBlockExceptionsDialog | Module implementing a dialog to configure the AdBlock exceptions.
AdBlockIcon | Module implementing the AdBlock icon for the main window status bar.
AdBlockManager | Module implementing the AdBlock manager.
AdBlockMatcher | Module implementing the AdBlock matcher.
AdBlockPage | Module implementing a class to apply AdBlock rules to a web page.
AdBlockRule | Module implementing the AdBlock rule class.
AdBlockSearchTree | Module implementing the AdBlock search tree.
AdBlockSubscription | Module implementing the AdBlock subscription class.
AdBlockTreeWidget | Module implementing a tree widget for the AdBlock configuration dialog.
AdBlockUrlInterceptor | Module implementing an URL interceptor base class.